@@ -8,7 +8,7 @@ use IPC::System::Simple;
 
 use Moo;
 use Boxer::Types qw( DataDir ClassDir NodeDir Suite );
-use Types::Standard qw( Str Undef );
+use Types::Standard qw( Maybe Str Undef );
 extends 'Boxer::Task';
 
 use File::BaseDir qw(data_dirs);
@@ -18,7 +18,7 @@ use YAML::XS;
 use Role::Commons -all;
 
 our $AUTHORITY = 'cpan:JONASS';
-our $VERSION   = 'v1.1.0';
+our $VERSION = 'v1.1.4';
 
 # permit callers to sloppily pass undefined values
 sub BUILDARGS
@@ -30,10 +30,10 @@ sub BUILDARGS
 
 has datadir => (
 	is       => 'lazy',
-	isa      => DataDir,
+	isa      => Maybe[DataDir],
 	coerce   => 1,
 	required => 1,
-	default  => sub { scalar( data_dirs( 'boxer', $_[0]->suite ) ) },
+	default  => sub { undef },
 );
 
 has suite => (
@@ -49,7 +49,7 @@ has classdir => (
 	isa      => ClassDir,
 	coerce   => 1,
 	required => 1,
-	default  => sub { $_[0]->datadir->child('classes') },
+	default  => sub { $_[0]->datadir ? $_[0]->datadir->child('classes') : scalar( data_dirs( 'boxer', $_[0]->suite, 'classes' ) ) },
 );
 
 has nodedir => (
